import csv
import sqlite3


def create_tables(conn):
    cur = conn.cursor()

    cur.execute('DROP TABLE IF EXISTS pet')
    cur.execute('DROP TABLE IF EXISTS pet_type')
    cur.execute('DROP TABLE IF EXISTS owner')

    cur.execute('CREATE TABLE pet_type(type_id INTEGER PRIMARY KEY, '
                '                      name TEXT UNIQUE)')
    cur.execute('CREATE TABLE owner(owner_id INTEGER PRIMARY KEY, '
                '                   name TEXT UNIQUE)')
    cur.execute('CREATE TABLE pet(pet_id INTEGER PRIMARY KEY, '
                '                 name TEXT, age INTEGER, type_id INTEGER, '
                '                 owner_id INTEGER, '
                '                 FOREIGN KEY (type_id) '
                '                     REFERENCES pet_type(type_id),'
                '                 FOREIGN KEY (owner_id) '
                '                     REFERENCES owner(owner_id))')
    conn.commit()


def insert_owner(conn, owner_name):
    cur = conn.cursor()

    cur.execute('INSERT OR IGNORE INTO owner(name) VALUES(?)', (owner_name,))
    conn.commit()

    cur.execute('SELECT owner_id FROM owner WHERE name = ?', (owner_name,))
    owner_id = cur.fetchone()[0]

    return owner_id


def insert_type(conn, type_name):
    cur = conn.cursor()

    cur.execute('INSERT OR IGNORE INTO pet_type(name) VALUES(?)', (type_name,))
    conn.commit()

    cur.execute('SELECT type_id FROM pet_type WHERE name = ?', (type_name,))
    owner_id = cur.fetchone()[0]

    return owner_id


def insert_pet(conn, name, age, owner_id, type_id):
    cur = conn.cursor()

    cur.execute('INSERT OR IGNORE INTO pet(name, age, owner_id, type_id)'
                'VALUES(?, ?, ?, ?)', (name, age, owner_id, type_id))
    conn.commit()


def main():
    conn = sqlite3.connect('pets.sqlite')

    cur = conn.cursor()
    cur.execute('PRAGMA foreign_keys = 1')
    cur.execute('PRAGMA journal_mode = WAL')
    cur.execute('PRAGMA synchronous = NORMAL')

    create_tables(conn)

    with open('pets.csv') as f:
        reader = csv.DictReader(f)
        rows = list(reader)

    for row in rows:
        type_id = insert_type(conn, row['Type'])
        owner_id = insert_owner(conn, row['Owner'])
        insert_pet(conn, row['Name'], row['Age'], owner_id, type_id)


if __name__ == '__main__':
    main()
