from data_sources import CsvSource, DatabaseSource


def choose(prompt, options):
    choice = None

    while choice is None:
        print(prompt)
        for i, option in enumerate(options):
            print(i + 1, '-', option)

        user_input = input('Enter your selection:')

        try:
            user_input = int(user_input)
            if 0 < user_input <= len(options):
                choice = options[user_input - 1]
            else:
                print('Invalid selection')
        except ValueError:
            print('You must enter an integer')

    return choice


def main():
    source = choose('Choose a data source:', ['CSV', 'Database'])

    if source == 'CSV':
        data_source = CsvSource('pets.csv')
    else:
        data_source = DatabaseSource('pets.sqlite')

    quit_program = False

    while not quit_program:
        choices = ['List all pets', 'List pets by owner', 'List pets by type',
                   'Quit']
        choice = choose('What would you like to do?', choices)

        if choice == 'List all pets':
            for pet in data_source.get_all_pets():
                print(pet)
        elif choice == 'List pets by owner':
            owner = input('Enter an owner name:')
            print('Here are the pets owned by', owner)
            for pet in data_source.get_pets_by_owner(owner):
                print(pet)
        elif choice == 'List pets by type':
            pet_type = input('Enter a pet type:')
            print('Here are the pets of type', pet_type)
            for pet in data_source.get_pets_by_type(pet_type):
                print(pet)
        else:
            quit_program = True


if __name__ == '__main__':
    main()
